@@ -5,15 +5,16 @@
  *
  */
 
-#ifndef MAILCOMMON_CRYPTOUTILS_H_
-#define MAILCOMMON_CRYPTOUTILS_H_
+#pragma once
 
 #include <KMime/Message>
 
 #include <mailcommon_export.h>
 
-namespace MailCommon {
-namespace CryptoUtils {
+namespace MailCommon
+{
+namespace CryptoUtils
+{
 Q_REQUIRED_RESULT MAILCOMMON_EXPORT KMime::Message::Ptr assembleMessage(const KMime::Message::Ptr &orig, const KMime::Content *newContent);
 Q_REQUIRED_RESULT MAILCOMMON_EXPORT KMime::Message::Ptr decryptMessage(const KMime::Message::Ptr &decrypt, bool &wasEncrypted);
 
@@ -27,5 +28,3 @@ MAILCOMMON_EXPORT void copyHeader(const KMime::Headers::Base *header, KMime::Mes
 Q_REQUIRED_RESULT MAILCOMMON_EXPORT bool isContentHeader(const KMime::Headers::Base *header);
 }
 }
-
-#endif
